------------------------------
-- AddOn Namespace
------------------------------
local MODNAME = "Skill Guide"
local addon   = LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L       = LibStub("AceLocale-3.0"):GetLocale(MODNAME)

------------------------------
-- Library Namespace
------------------------------
local config = LibStub("AceConfig-3.0")
local reg    = LibStub("AceConfigRegistry-3.0")
local dialog = LibStub("AceConfigDialog-3.0")

-- Get the private table
local private = select(2, ...)

local modularOptions = {}

local function getProfiles()
  return LibStub("AceDBOptions-3.0"):GetOptionsTable(addon.db)
end

local options
local function fullOptions()
  if not options then
      
    options = {
      name = addonName,
      desc = "Configuation options for " .. MODNAME,
      type = "group",
      args = {
        faq = {
          faq_header = {
            name = "FAQ",
            desc = "Frequently Asked Questions",
            type = "header",
            order = 1
          },
          faq_q1 = {
            name = private.colors["TURQUOISE"] .. "Q: What is Skill Guide used for?",
            desc = "Question 1 of the FAQ",
            type = "description",
            order = 2
          },
          faq_a1 = {
            name = private.colors["ORANGE"] .. "A: Skill Guide is an in-game tradeskill guide used for both power leveling or leveling any trade skill.",
            desc = "Answer 1 of the FAQ",
            type = "description",
            order = 3
          },
          spacer_1 = {
            name = "\n",
            desc = "spacer",
            type = "description",
            order = 4
          },
          faq_q2 = {
            name = private.colors["TURQUOISE"] .. "Q: How does this differ from a browser guide such as wow-professions.com?",
            desc = "Question 1 of the FAQ",
            type = "description",
            order = 5
          },
          faq_a2 = {
            name = private.colors["ORANGE"] .. "A: Browser guides are the suggested route someone should take if they want to power level and either have the gold to buy the mats or the time to farm them. These are commonly the opinion of the author and if you didn't, or couldn't, aquire the same recipes then you must figure out for yourself how to get those few skill ups your self. SkillGuide looks at the recipes you currently own and uses a series of calculatons to find the \"cheapest\" skill up possible. If you have no recipes that can provide a skill up, then it will point you to either a trainer or a vender that has the optimal recipe.",
            desc = "Answer 1 of the FAQ",
            type = "description",
            order = 6
          },
          spacer_2 = {
            name = "\n",
            desc = "spacer",
            type = "description",
            order = 7
          },
          faq_q3 = {
            name = private.colors["TURQUOISE"] .. "Q: what happens when a new recipe or tradeskill is added? Do I have to wait for you to update to be told about these recipes?",
            desc = "Question 1 of the FAQ",
            type = "description",
            order = 8
          },
          faq_a3 = {
            name = private.colors["ORANGE"] .. "A: Skill Guide learns new recipes as you do. Since you can't skill up on something you haven't learned, why bother including it in the calculations?",
            desc = "Answer 1 of the FAQ",
            type = "description",
            order = 9
          },
        }, -- end of FAQ
      } -- end of args
    } -- end of options
  
    for k,v in pairs(modularOptions) do
      options.args[k] = (type(v) == "function") and v() or v
    end
  end -- of if not options
   
  return options
end

function addon:SetupOptions()
  reg:RegisterOptionsTable(MODNAME, fullOptions)
  self.optionsFrame = dialog:AddToBlizOptions(MODNAME, nil, nil, "faq")
  
  -- Register the module options
  self:RegisterModuleOptions("Profiles", getProfiles(), L["Profiles"])
  
  -- Add the About Panel from LibAboutPanel
  if LibStub:GetLibrary("LibAboutPanel", true) then
    self.optionsFrame["About"] = LibStub:GetLibrary("LibAboutPanel").new(MODNAME, MODNAME)
  else
    self:Print("LibAboutPanel not loaded.")
  end
end

function addon:RegisterModuleOption(name, optionsTable, displayName)
  modularOptions[name] = optionsTable
  self.optionsFrame[name] = dialog:AddToBlizOptions(MODNAME, displayName, MODNAME, name)
end
